//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[Hora](index.md)/[pattern](pattern.md)

# pattern

[common]\
val [pattern](pattern.md): [HoraHandPattern](../-hora-hand-pattern/index.md)

和牌形
